/*+----------------------------------------------------------------+
  | Copyright (c) 2012 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved.
  | Name:     etldlfct.sas
  | Purpose:  Delete fact data from SDM
  |
  | Parameters:
  |
  !     table is the table holding Dimension and Member codes.
  |     This table can be created in the transformation pre-code area.
  |     The table must have SAS_DIM_CODE and SAS_MBR_CODE columns.
  |     The SAS code below creates an example table:
  |        data WORK.BASE_FACT_dimMbrSelection;
  |           length SAS_DIM_CODE SAS_MBR_CODE $32 ;
  |           SAS_DIM_CODE = "TIME_DIM" ;
  |           SAS_MBR_CODE = "JAN2003";
  |           output ;
  |           SAS_MBR_CODE = "FEB2003" ;
  |           output ;
  |           SAS_DIM_CODE = "ANALYSIS_DIM";
  |           SAS_MBR_CODE = "ACTUAL" ;
  |            output ;
  |           SAS_MBR_CODE = "BUDGET" ;
  |           output ;
  |        run ;
  +----------------------------------------------------------------+*/


%macro etldlfct(cycle, table, deleteFormData, environment);

  proc sort data=&table nodups;
    by SAS_DIM_CODE SAS_MBR_CODE;
  run;  

  data _null_;
    set &table nobs=_nobs;
    call symput('_nobs', _nobs);
    stop;
  run;

  data _null_ /picklist='finance/finance.txt' saveclassl="finbatch" getclassl="finbatch";

    array dimCodes[&_nobs] $32 ;
    array mbrCodes[&_nobs] $32 ;
    retain cnt 1 ;
    retain dimCodes mbrCodes;

    set &table end=nRunJavaOBJ;

    dimCodes[cnt] = strip(sas_dim_code);
    mbrCodes[cnt] = strip(sas_mbr_code);
    cnt + 1;

    if nRunJavaOBJ then do;

      dcl javaobj j("com/sas/solutions/finance/api/BaseFactLoad");
      j.ExceptionDescribe(1);

      if symget("environment") ne "" then
        j.callVoidMethod("setEnvironment", "&environment");

      call METADATA_PASSID("j", "");

      length delcntstr $20;
      length cycle $ 100;
      length msg $ 512;
      length url $ 1000;
      length count $ 7;
      table=symget("table");
      cycle=symget("cycle");
      deleteFormData=symget("deleteFormData");

      put cycle= table= deleteFormData=;

      j.callStringMethod("deleteFacts", strip(cycle), dimCodes, mbrCodes, strip(deleteFormData), delcntstr);

      j.callStringMethod("getMessage", msg);

      delcnt = input(strip(delcntstr), best20.);
      put delcntstr= delcnt= msg= ;

      /*  Status handling  */
      if delcnt ge 0 then do;
         * delete successful ;
         j.callStringMethod("getTransactionsCount", count);
         put 'NOTE: Successfully deleted ' delcntstr 'facts.';
         j.callVoidMethod("logout");
         j.delete();
      end;
      else if strip(delcntstr) = "-999" then do;
         * delete failed - no valid SOURCE members ;
         put 'ERROR: No valid SOURCE members defined.';

         j.callVoidMethod("logout");
         j.delete();
         *abort ;
      end;
      else if strip(delcntstr) = "-9999" then do;
         * delete failed - server exception;
         put 'ERROR: ' msg;

         j.callVoidMethod("logout");
         j.delete();
         *abort ;
      end;

    end;
  run;

%mend;
